#!/usr/bin/make -f
# -*- makefile -*-

# get-tarball.make
# version 2011-07-15

# download tarball, checkout from git or svn, clean download and create orig tarball
# place the following 2 lines to your debian/rules and modify the configuration below
#get-tarball:
#	$(MAKE) -f debian/get-tarball.make $@

# don't touch these DEB*
DEB_SOURCE_PACKAGE := $(strip $(shell egrep '^Source: ' debian/control | cut -f 2 -d ':'))
DEB_VERSION := $(shell dpkg-parsechangelog | egrep '^Version:' | cut -f 2 -d ' ')
DEB_NOEPOCH_VERSION := $(shell echo $(DEB_VERSION) | cut -d: -f2-)
DEB_UPSTREAM_VERSION := $(shell echo $(DEB_NOEPOCH_VERSION) | sed -e 's/-[^-]*$$//')
DEB_VS_REVISION := $(shell echo $(DEB_UPSTREAM_VERSION) | sed -e 's/.*+\(svn\|git\|cvs\|bzr\|rev\|r\)//')

# configuration:
#DL_URL := http://webhost/download/$(DEB_SOURCE_PACKAGE)-$(DEB_UPSTREAM_VERSION).tar.gz
#DL_UNPACK := tar -xzf
#GIT_URL := git://git.$(DEB_SOURCE_PACKAGE).org/$(DEB_SOURCE_PACKAGE).git
GIT_URL := git://github.com/280north/narwhal.git
#SVN_URL := https://$(DEB_SOURCE_PACKAGE).svn.sourceforge.net/svnroot/$(DEB_SOURCE_PACKAGE)@$(DEB_VS_REVISION)
#SVN_URL := http://$(DEB_SOURCE_PACKAGE).googlecode.com/svn/trunk@$(DEB_VS_REVISION)
#SVN_URL := https://svnhost/svnroot/$(DEB_SOURCE_PACKAGE)/tags/$(DEB_UPSTREAM_VERSION)
#WITH_SUBMODULES := true
#DONT_CLEAN_CHECKOUT := true
#RM_FILES := @FILES_TO_DELETE@
#FIND_RM_FILES := @FILES_TO_SEARCH_FOR_AND_DELETE@
TARBALL_COMPRESSION := xz
TARBALL_COMPRESSION_LEVEL := 6

download-tarball:
	@echo '>>>' "Downloading tarball (if any)..."
	if [ "$(DL_URL)" ] && [ "$(DL_UNPACK)" ]; then \
	    wget $(DL_URL) -O tarball.bin; \
	    mkdir unpack; \
	    cd unpack; $(DL_UNPACK) ../tarball.bin; cd ..; \
	    if  [ $$(find unpack/ -mindepth 1 -maxdepth 1 | wc -l) -eq 1 ] && \
	        [ -d $$(find unpack/ -mindepth 1 -maxdepth 1) ]; \
	    then \
	        mv $$(find unpack/ -mindepth 1 -maxdepth 1) $(DEB_SOURCE_PACKAGE)-$(DEB_UPSTREAM_VERSION); \
	        rmdir unpack; \
	    else \
	        mv unpack $(DEB_SOURCE_PACKAGE)-$(DEB_UPSTREAM_VERSION); \
	    fi; \
	    rm -f tarball.bin; \
	fi

download-source: download-tarball

checkout-git-source:
	@echo '>>>' "Checkout from git (if any)..."
	if [ "$(GIT_URL)" ]; then \
	    git clone $(GIT_URL) $(DEB_SOURCE_PACKAGE)-$(DEB_UPSTREAM_VERSION); \
	fi
	if [ "$(GIT_URL)" ] && [ "$(WITH_SUBMODULES)" = true ]; then \
	    pwd=$$(pwd); \
	    while [ "$$(find $(DEB_SOURCE_PACKAGE)-$(DEB_UPSTREAM_VERSION) -name .gitmodules)" ]; do \
	        find $(DEB_SOURCE_PACKAGE)-$(DEB_UPSTREAM_VERSION) -name .gitmodules | \
	        while read m; do \
	            cd $$(dirname "$$m"); \
	            git submodule update --init && \
	            mv .gitmodules .gitmodules.done; \
	            cd $$pwd; \
	        done; \
	    done; \
	    find $(DEB_SOURCE_PACKAGE)-$(DEB_UPSTREAM_VERSION) -name .gitmodules.done  | \
	    while read m; do mv "$$m" $$(dirname "$$m")/$$(basename "$$m" .done); done; \
	fi

checkout-svn-source:
	@echo '>>>' "Checkout from svn (if any)..."
	if [ "$(SVN_URL)" ]; then \
	    svn co $(SVN_URL) $(DEB_SOURCE_PACKAGE)-$(DEB_UPSTREAM_VERSION); \
	fi

checkout-source: checkout-git-source checkout-svn-source

clean-checkout:
	if [ "$(DONT_CLEAN_CHECKOUT)" != true ]; then \
	    for f in .svn .git .gitignore .gitmodules; do \
	        find $(DEB_SOURCE_PACKAGE)-$(DEB_UPSTREAM_VERSION) -name "$$f" -exec rm -rf {} \; 2>/dev/null || true; \
	    done; \
	fi

clean-tarball:
	@echo '>>>' "Clean tarball..."
	[ ! -d "$(DEB_SOURCE_PACKAGE)-$(DEB_UPSTREAM_VERSION)/debian" ] || \
	    mv "$(DEB_SOURCE_PACKAGE)-$(DEB_UPSTREAM_VERSION)/debian" "$(DEB_SOURCE_PACKAGE)-$(DEB_UPSTREAM_VERSION)/debian.dist"
	[ ! "$(RM_FILES)" ] || \
	    cd $(DEB_SOURCE_PACKAGE)-$(DEB_UPSTREAM_VERSION) && \
	    rm -rf $(RM_FILES)
	[ ! "$(FIND_RM_FILES)" ] || \
	    for f in $(FIND_RM_FILES); do \
	        find $(DEB_SOURCE_PACKAGE)-$(DEB_UPSTREAM_VERSION)/ -name "$$f" -exec rf -rf {} \; 2>/dev/null || true; \
	    done

build-tarball: clean-tarball clean-checkout
	@echo '>>>' "Build tarball..."
	tar -cf ../$(DEB_SOURCE_PACKAGE)_$(DEB_UPSTREAM_VERSION).orig.tar $(DEB_SOURCE_PACKAGE)-$(DEB_UPSTREAM_VERSION)/
	$(TARBALL_COMPRESSION) -$(TARBALL_COMPRESSION_LEVEL) ../$(DEB_SOURCE_PACKAGE)_$(DEB_UPSTREAM_VERSION).orig.tar
#	#tar -cf- $(DEB_SOURCE_PACKAGE)-$(DEB_UPSTREAM_VERSION)/ | \
#	#    $(TARBALL_COMPRESSION) -$(TARBALL_COMPRESSION_LEVEL) -c > ../$(DEB_SOURCE_PACKAGE)_$(DEB_UPSTREAM_VERSION).orig.tar.$(TARBALL_COMPRESSION)
	rm -rf $(DEB_SOURCE_PACKAGE)-$(DEB_UPSTREAM_VERSION)
	@echo '>>>' "Done."

get-tarball: download-source checkout-source build-tarball
